@@ -1,16 +1,18 @@
 package Convert::CEGH::Gematria;
+use warnings;
+use strict;
 use utf8;
 use Regexp::Ethiopic qw(:forms setForm);
 
 BEGIN
 {
 use base qw( Exporter );
-use vars qw( $አበገደሀ $תיבפלא $ΑΛΦΑΒΕΤ %Gematria @EXPORT_OK $VERSION $use_halehame );
+use vars qw( $አበገደ $ሀለሐመ  $תיבפלא $ΑΛΦΑΒΕΤ %Gematria @EXPORT_OK $VERSION $use_halehame );
 
 
 	@EXPORT_OK = qw( enumerate );
 
-	$VERSION = "0.02";
+	$VERSION = "0.03";
 
 	#
 	# Gematria Data:
@@ -127,7 +129,7 @@ my ( @strings ) = @_;
 
 __END__
 
-
+=encoding utf8
 
 =head1 NAME
 
@@ -174,6 +176,13 @@ None presently known.
 
 Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
 =head1 SEE ALSO
 
 L<Convert::CEGH::Transliterate>
