@@ -1,4 +1,6 @@
 package Convert::CEGH::Transliterate;
+use warnings;
+use strict;
 use utf8;
 use Regexp::Ethiopic qw(:forms setForm);
 
@@ -9,7 +11,7 @@ use vars qw( $COPTIC @EXPORT_OK $VERSION );
 
 	@EXPORT_OK = qw( transliterate );
 
-	$VERSION = "0.01";
+	$VERSION = "0.03";
 
 	$COPTIC = qr/[ϚCϢϤϦϨϬϮϪ]/;
 }
@@ -132,7 +134,7 @@ my ( $to, @strings ) = @_;
 
 __END__
 
-
+=encoding utf8
 
 =head1 NAME
 
@@ -206,6 +208,13 @@ None presently known.
 
 Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
 =head1 SEE ALSO
 
 L<Convert::CEGH::Gematria>
